[![PyPI version](https://badge.fury.io/py/pydecon.svg)](https://badge.fury.io/py/pydecon)
[![Anaconda version](https://anaconda.org/david-hoffman/pydecon/badges/downloads.svg)](https://anaconda.org/david-hoffman/pydecon)
[![Conda Badge](https://anaconda.org/david-hoffman/pydecon/badges/installer/conda.svg)](https://anaconda.org/david-hoffman/pydecon)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![ci](https://github.com/david-hoffman/pydecon/workflows/ci/badge.svg)](https://github.com/david-hoffman/pydecon/actions?query=workflow%3Aci)
[![Create Release](https://github.com/david-hoffman/pydecon/workflows/Create%20Release/badge.svg)](https://github.com/david-hoffman/pydecon/actions?query=workflow%3A%22Create+Release%22)

# pydecon

A library stub that implements different deconvolution algorithms. At this point only Richardson-Lucy is supported.

## MORE TO COME!

## Installation

Installation is simplest with `conda` or `pip`:

```bash
conda install -c david-hoffman pydecon
```

```bash
pip install pydecon
```